@@ -1,7 +1,7 @@
 import os
 import socket
 
-from mitmproxy.utils import data, compat
+from mitmproxy.utils import data
 
 import pytest
 
@@ -17,16 +17,6 @@ skip_not_windows = pytest.mark.skipif(
     reason='Skipping due to not Windows'
 )
 
-skip_appveyor = pytest.mark.skipif(
-    "APPVEYOR" in os.environ,
-    reason='Skipping due to Appveyor'
-)
-
-skip_new_proxy_core = pytest.mark.skipif(
-    compat.new_proxy_core,
-    reason='Skipping legacy test for old proxy core'
-)
-
 try:
     s = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
     s.bind(("::1", 0))
