@@ -1,10 +1,8 @@
 import io
 import pytest
 from unittest.mock import patch
-
 from mitmproxy.test import tflow
-
-from mitmproxy import flowfilter
+from mitmproxy import flowfilter, http
 
 
 class TestParsing:
@@ -24,6 +22,10 @@ class TestParsing:
         assert flowfilter.parse("~m foobar")
         assert flowfilter.parse("~u foobar")
         assert flowfilter.parse("~q ~c 10")
+        assert flowfilter.parse("~replay")
+        assert flowfilter.parse("~replayq")
+        assert flowfilter.parse("~replays")
+        assert flowfilter.parse("~comment .")
         p = flowfilter.parse("~q ~c 10")
         self._dump(p)
         assert len(p.lst) == 2
@@ -141,9 +143,16 @@ class TestMatchingHTTPFlow:
     def test_fmarked(self):
         q = self.req()
         assert not self.q("~marked", q)
-        q.marked = True
+        q.marked = ":default:"
         assert self.q("~marked", q)
 
+    def test_fmarker_char(self):
+        t = tflow.tflow()
+        t.marked = ":default:"
+        assert not self.q("~marker X", t)
+        t.marked = 'X'
+        assert self.q("~marker X", t)
+
     def test_head(self):
         q = self.req()
         s = self.resp()
@@ -254,7 +263,7 @@ class TestMatchingHTTPFlow:
         assert not self.q("~src :99", q)
         assert self.q("~src 127.0.0.1:22", q)
 
-        q.client_conn.address = None
+        q.client_conn.peername = None
         assert not self.q('~src address:22', q)
         q.client_conn = None
         assert not self.q('~src address:22', q)
@@ -296,6 +305,31 @@ class TestMatchingHTTPFlow:
         assert self.q("!~c 201 !~c 202", s)
         assert not self.q("!~c 201 !~c 200", s)
 
+    def test_replay(self):
+        f = tflow.tflow()
+        assert not self.q("~replay", f)
+        f.is_replay = "request"
+        assert self.q("~replay", f)
+        assert self.q("~replayq", f)
+        assert not self.q("~replays", f)
+        f.is_replay = "response"
+        assert self.q("~replay", f)
+        assert not self.q("~replayq", f)
+        assert self.q("~replays", f)
+
+    def test_metadata(self):
+        f = tflow.tflow()
+        f.metadata["a"] = 1
+        f.metadata["b"] = "string"
+        f.metadata["c"] = {"key": "value"}
+        assert self.q("~meta a", f)
+        assert not self.q("~meta no", f)
+        assert self.q("~meta string", f)
+        assert self.q("~meta key", f)
+        assert self.q("~meta value", f)
+        assert self.q("~meta \"b: string\"", f)
+        assert self.q("~meta \"'key': 'value'\"", f)
+
 
 class TestMatchingTCPFlow:
 
@@ -424,12 +458,9 @@ class TestMatchingTCPFlow:
 
 class TestMatchingWebSocketFlow:
 
-    def flow(self):
+    def flow(self) -> http.HTTPFlow:
         return tflow.twebsocketflow()
 
-    def err(self):
-        return tflow.twebsocketflow(err=True)
-
     def q(self, q, o):
         return flowfilter.parse(q)(o)
 
@@ -437,10 +468,10 @@ class TestMatchingWebSocketFlow:
         f = self.flow()
         assert self.q("~websocket", f)
         assert not self.q("~tcp", f)
-        assert not self.q("~http", f)
+        assert self.q("~http", f)
 
     def test_handshake(self):
-        f = self.flow().handshake_flow
+        f = self.flow()
         assert self.q("~websocket", f)
         assert not self.q("~tcp", f)
         assert self.q("~http", f)
@@ -450,10 +481,6 @@ class TestMatchingWebSocketFlow:
         f = tflow.tflow(resp=True)
         assert not self.q("~websocket", f)
 
-    def test_ferr(self):
-        e = self.err()
-        assert self.q("~e", e)
-
     def test_domain(self):
         q = self.flow()
         assert self.q("~d example.com", q)
@@ -465,9 +492,6 @@ class TestMatchingWebSocketFlow:
         assert self.q("~u example.com/ws", q)
         assert not self.q("~u moo/path", q)
 
-        q.handshake_flow = None
-        assert not self.q("~u example.com", q)
-
     def test_body(self):
         f = self.flow()
 
@@ -585,6 +609,10 @@ class TestMatchingDummyFlow:
 
         assert not self.q("~q", f)
 
+        assert not self.q("~comment .", f)
+        f.comment = "comment"
+        assert self.q("~comment .", f)
+
 
 @patch('traceback.extract_tb')
 def test_pyparsing_bug(extract_tb):
