@@ -1,9 +1,9 @@
+import asyncio
 import json as _json
 import logging
-from unittest import mock
 import os
-import asyncio
 import sys
+from unittest import mock
 
 import pytest
 
@@ -331,14 +331,18 @@ class TestApp(tornado.testing.AsyncHTTPTestCase):
         # Set some value as constant, so that _tflow.js would not change every time.
         _tflow['client_conn']['id'] = "4a18d1a0-50a1-48dd-9aa6-d45d74282939"
         _tflow['id'] = "d91165be-ca1f-4612-88a9-c0f8696f3e29"
-        _tflow['error']['timestamp'] = 1495370312.4814785
-        _tflow['response']['timestamp_end'] = 1495370312.4814625
-        _tflow['response']['timestamp_start'] = 1495370312.481462
         _tflow['server_conn']['id'] = "f087e7b2-6d0a-41a8-a8f0-e1a4761395f8"
+        _tflow["request"]["trailers"] = [["trailer", "qvalue"]]
+        _tflow["response"]["trailers"] = [["trailer", "qvalue"]]
         tflow_json = _json.dumps(_tflow, indent=4, sort_keys=True)
         here = os.path.abspath(os.path.dirname(__file__))
         web_root = os.path.join(here, os.pardir, os.pardir, os.pardir, os.pardir, 'web')
         tflow_path = os.path.join(web_root, 'src/js/__tests__/ducks/_tflow.js')
-        content = f"""export default function(){{\n    return {tflow_json}\n}}"""
+        content = (
+            f"/** Auto-generated by test_app.py:TestApp._test_generate_tflow_js */\n"
+            f"export default function(){{\n"
+            f"    return {tflow_json}\n"
+            f"}}"
+        )
         with open(tflow_path, 'w', newline="\n") as f:
             f.write(content)
