@@ -1,5 +1,5 @@
 import React from 'react'
 
 export default function HideInStatic({ children }) {
-    return global.MITMWEB_STATIC ? null : [children]
+    return window.MITMWEB_STATIC ? null : [children]
 }
